*********
Tutorials
*********

.. toctree::

   notebooks/01_intro_to_mendeleev.ipynb
   notebooks/02_tables.ipynb


Jupyter notebooks
=================

A series of short tutorials is available as `Jupyter <https://jupyter.org/>`_
notebooks that present the main functionality and provide real-life examples

* `Introduction <http://nbviewer.jupyter.org/url/bitbucket.org/lukaszmentel/mendeleev/raw/tip/docs/source/notebooks/01_intro_to_mendeleev.ipynb>`_
* `Gettin tables <http://nbviewer.jupyter.org/url/bitbucket.org/lukaszmentel/mendeleev/raw/tip/docs/source/notebooks/02_tables.ipynb>`_
* `Plotting periodic tables <http://nbviewer.jupyter.org/url/bitbucket.org/lukaszmentel/mendeleev/raw/tip/docs/source/notebooks/03_plotting.ipynb>`_
